@@ -96,6 +96,9 @@ class DistributeStatus(object):
     # 虚拟已确收
     CUS_CONFIRM_AT_VIRTUAL = "cus_confirm_at_virtual"
 
+    # 2022.09 特需售后单自提转快递支付运费订单的发货单
+    MAKEUP_POSTAGE_PAID = "paid"
+
     NO_SPLIT_STATUS_LIST = [
         INIT,
         HGVENDING_INIT,
@@ -126,6 +129,7 @@ class DistributeStatus(object):
         HAITAO_PACKAGED,
         HAITAO_RETURN,
         SERVICE_STOP,
+        MAKEUP_POSTAGE_PAID,
     ]
     
 
@@ -145,6 +149,7 @@ class DistributeStatus(object):
         OUTSTORAGE_WAIT_PACKAGE,
         OUTSTORAGE_PACKAGED,
         SERVICE_STOP,
+        MAKEUP_POSTAGE_PAID,
     ]
 
     ## 初始态集合
@@ -162,7 +167,9 @@ class DistributeStatus(object):
         PRINTED,
         GUIDE_PICKED_UP,
         SPLIT,
-        HGVENDING_WAIT_PICKUP
+        HGVENDING_WAIT_PICKUP,
+        # 补缴运费的商品可以整单退
+        MAKEUP_POSTAGE_PAID,
     ]
 
     BEFORE_cuservice_pick_up = [
@@ -215,6 +222,7 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: "已发货",
         HAITAO_RETURN: "售后",
         SERVICE_STOP: "待发货",
+        MAKEUP_POSTAGE_PAID: "运费已支付",
     }
     # For B端 查询
     DISTRIBUTE_STATUS_CHOICES_FOR_B_QUERY = {
@@ -246,7 +254,8 @@ class DistributeStatus(object):
         HAITAO_BAISHI: "海淘已推百世",
         HAITAO_PACKAGED: "海淘已发货",
         HAITAO_RETURN: "海淘已退",
-        SERVICE_STOP: "滞留仓已收"
+        SERVICE_STOP: "滞留仓已收",
+        MAKEUP_POSTAGE_PAID: "运费已支付",
     }
 
     DISTRIBUTE_MESSAGE_DICT_FOR_C = {
@@ -274,6 +283,7 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: "海淘已发货。",
         HAITAO_RETURN: "海淘已售后。",
         SERVICE_STOP: "暂时无法发货，商品滞留。",
+        MAKEUP_POSTAGE_PAID: "订单自提转快递运费已支付。",
     }
 
     DISTRIBUTE_STATUS_CHOICES = (
@@ -307,6 +317,7 @@ class DistributeStatus(object):
         (SERVICE_STOP, "滞留仓已收"),
         (VIRTUAL_INIT, "虚拟商品初始态"),
         (CUS_CONFIRM_AT_VIRTUAL, "虚拟商品已提货"),
+        (MAKEUP_POSTAGE_PAID, "运费已支付"),
     )
 
     DISTRIBUTE_STATUS_OWNER_DICT = {
@@ -339,6 +350,7 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: DistributeStatusOwner.HAITAO,
         HAITAO_RETURN: DistributeStatusOwner.HAITAO,
         SERVICE_STOP: DistributeStatusOwner.CUSSERVICE,
+        MAKEUP_POSTAGE_PAID: DistributeStatusOwner.CUSTOMER,
     }
 
     DISTRIBUTE_STATUS_DIRECTION_DICT = {
@@ -370,6 +382,8 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: DistributeDirection.HAITAO,
         HAITAO_RETURN: DistributeDirection.HAITAO,
         SERVICE_STOP: DistributeDirection.CUSSERVICE,
+
+        MAKEUP_POSTAGE_PAID: DistributeDirection.CUSSERVICE,
     }
 
     # 终结状态列表
@@ -392,7 +406,8 @@ class DistributeStatus(object):
         TAILPAY_OVERTIME,
         # 海淘
         HAITAO_PACKAGED,
-        HAITAO_RETURN
+        HAITAO_RETURN,
+        MAKEUP_POSTAGE_PAID,
     ]
 
     # 非最终状态
@@ -425,6 +440,16 @@ class DistributeStatus(object):
         CUS_CONFIRM_AT_CUSSERVICE,
     ]
 
+    # 未售后的不支持修改配送方式的发货单状态
+    CAN_NOT_MODY_SHIPPING_METHOD_DISTRIBUTE_STATUS_LIST = [
+        CUS_CONFIRM_AT_GUIDE,
+        CUS_CONFIRM_AT_CUSSERVICE,
+        PACKAGED,
+        OUTSTORAGE_PACKAGED,
+        OUTSTORAGE_WAIT_PACKAGE,
+        SPLIT,
+    ]
+
 
 class ShippingMethod(object):
     # 普通快递
@@ -542,6 +567,8 @@ class DistributeEventConst(object):
     AFSPLUS_OPEN = "afsplus_open"
     AFSPLUS_CLOSE = "afsplus_close"
     AFSPLUS_COMPLETE = "afsplus_complete"
+    AFSPLUS_S2E = "afsplus_s2e"  # 自提转快递
+    AFSPLUS_E2S = "afsplus_e2s"  # 快递转自提
 
     # 2022.08 虚拟商品确收
     CUS_CONFIRM_AT_VIRTUAL = "cus_confirm_at_virtual"
@@ -690,6 +717,7 @@ class DistributeEventConst(object):
                 DistributeStatus.HAITAO_INIT,
                 DistributeStatus.DEPOSITPAY,
                 DistributeStatus.TAILPAY_OVERTIME,
+                DistributeStatus.MAKEUP_POSTAGE_PAID,
             ],
 
             DistributeEventConstKey.TO_STATE_MAP_KEY: {
@@ -713,8 +741,9 @@ class DistributeEventConst(object):
                 DistributeStatus.HAITAO_INIT: None,
                 DistributeStatus.DEPOSITPAY: None,
                 DistributeStatus.SERVICE_STOP: DistributeStatus.SPLIT,
-            #    DistributeStatus.HAITAO_INIT: None,
+                # DistributeStatus.HAITAO_INIT: None,
                 DistributeStatus.TAILPAY_OVERTIME: None,
+                DistributeStatus.MAKEUP_POSTAGE_PAID: None,
             },
         },
         CLOSE_AFTERSALE: {
@@ -732,6 +761,7 @@ class DistributeEventConst(object):
                 DistributeStatus.SERVICE_STOP,
                 DistributeStatus.DEPOSITPAY,
                 DistributeStatus.TAILPAY_OVERTIME,
+                DistributeStatus.MAKEUP_POSTAGE_PAID,
                 ],
             DistributeEventConstKey.TO_STATUS_KEY: None,
         },
@@ -747,6 +777,7 @@ class DistributeEventConst(object):
                 DistributeStatus.HAITAO_INIT,
                 DistributeStatus.DEPOSITPAY,
                 DistributeStatus.TAILPAY_OVERTIME,
+                DistributeStatus.MAKEUP_POSTAGE_PAID,
                 ],
             DistributeEventConstKey.TO_STATE_MAP_KEY: {
                 DistributeStatus.INIT: DistributeStatus.NO_PICKUP_RETURN,
@@ -762,6 +793,7 @@ class DistributeEventConst(object):
                 DistributeStatus.DEPOSITPAY: DistributeStatus.DEPOSITPAY_RETURN,
                 DistributeStatus.TAILPAY_OVERTIME: DistributeStatus.DEPOSITPAY_RETURN,
                 DistributeStatus.CUS_CONFIRM_AT_VIRTUAL: None,
+                DistributeStatus.MAKEUP_POSTAGE_PAID: None,
             }
         },
         CREATE_EXPRESS: {
@@ -931,6 +963,29 @@ class DistributeEventConst(object):
             ],
             DistributeEventConstKey.TO_STATUS_KEY: None
         },
+        AFSPLUS_S2E: {
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT, DistributeStatus.PRINTED,
+                                DistributeStatus.CUSSERVICE_PICKED_UP,
+                                DistributeStatus.GUIDE_PICKED_UP,
+                                DistributeStatus.SERVICE_DESK,
+                                DistributeStatus.SERVICE_STORE,
+                                DistributeStatus.SERVICE_STOP,
+            ],
+            DistributeEventConstKey.TO_STATUS_KEY: None
+        },
+        AFSPLUS_E2S: {
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT, DistributeStatus.PRINTED,
+                                DistributeStatus.CUSSERVICE_PICKED_UP,
+                                DistributeStatus.GUIDE_PICKED_UP,
+                                DistributeStatus.SERVICE_DESK,
+                                DistributeStatus.SERVICE_STORE,
+                                DistributeStatus.SERVICE_STOP,
+            ],
+            DistributeEventConstKey.TO_STATUS_KEY: None
+        },
+
         # 2022.08 虚拟商品确收事件
         CUS_CONFIRM_AT_VIRTUAL: {
             DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
@@ -1017,6 +1072,8 @@ class DistributeEventConst(object):
         AFSPLUS_OPEN: "申请特殊售后",
         AFSPLUS_CLOSE: "取消特殊售后",
         AFSPLUS_COMPLETE: "完成特殊售后",
+        AFSPLUS_S2E: "自提转快递",  # 自提转快递
+        AFSPLUS_E2S: "快递转自提",  # 快递转自提
 
         # 虚拟商品
         CUS_CONFIRM_AT_VIRTUAL: "虚拟商品确收"
